Client library for Yamcs.

## Development Setup

Install build dependencies (you may want to do this in a virtualenv):

    pip install -r requirements.txt


Install `yamcs-client` from the source base:

    python setup.py develop

Changes to any source file have immediate impact.
